@@ -194,7 +194,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
-            'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'trust_id': '',
             'auth_url': 'http://192.168.10.10:5000/v3',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
@@ -236,6 +236,10 @@ class TestClusterConductorWithK8s(base.TestCase):
                           'RegionOne',
                           group='docker_registry')
 
+        CONF.set_override('cluster_user_trust',
+                          True,
+                          group='trust')
+
         (template_path,
          definition,
          env_files) = mock_driver()._extract_template_definition(self.context,
@@ -350,7 +354,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'ssh_key_name': 'keypair_id',
             'tenant_name': 'fake_tenant',
             'tls_disabled': False,
-            'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'trust_id': '',
             'trustee_domain_id': 'trustee_domain_id',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
@@ -421,7 +425,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
-            'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'trust_id': '',
             'auth_url': 'http://192.168.10.10:5000/v3',
             'cluster_uuid': self.cluster_dict['uuid'],
             'magnum_url': self.mock_osc.magnum_url.return_value,
@@ -488,7 +492,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
-            'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'trust_id': '',
             'auth_url': 'http://192.168.10.10:5000/v3',
             'cluster_uuid': self.cluster_dict['uuid'],
             'magnum_url': self.mock_osc.magnum_url.return_value,
@@ -686,7 +690,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
-            'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'trust_id': '',
             'auth_url': 'http://192.168.10.10:5000/v3',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
