@@ -258,6 +258,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'system_pods_initial_delay')
         system_pods_timeout = mock_cluster_template.labels.get(
             'system_pods_timeout')
+        admission_control_list = mock_cluster_template.labels.get(
+            'admission_control_list')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -272,6 +274,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'flannel_backend': flannel_backend,
             'system_pods_initial_delay': system_pods_initial_delay,
             'system_pods_timeout': system_pods_timeout,
+            'admission_control_list': admission_control_list,
             'username': 'fake_user',
             'tenant_name': 'fake_tenant',
             'magnum_url': mock_osc.magnum_url.return_value,
@@ -320,6 +323,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'system_pods_initial_delay')
         system_pods_timeout = mock_cluster_template.labels.get(
             'system_pods_timeout')
+        admission_control_list = mock_cluster_template.labels.get(
+            'admission_control_list')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -334,6 +339,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'flannel_backend': flannel_backend,
             'system_pods_initial_delay': system_pods_initial_delay,
             'system_pods_timeout': system_pods_timeout,
+            'admission_control_list': admission_control_list,
             'username': 'fake_user',
             'tenant_name': 'fake_tenant',
             'magnum_url': mock_osc.magnum_url.return_value,
